@@ -327,31 +327,6 @@ miner_list (gboolean available,
 	return EXIT_SUCCESS;
 }
 
-static gboolean
-miner_get_details (TrackerMinerManager  *manager,
-                   const gchar          *miner,
-                   gchar               **status,
-                   gdouble              *progress,
-                   GStrv                *pause_applications,
-                   GStrv                *pause_reasons)
-{
-	if ((status || progress) &&
-	    !tracker_miner_manager_get_status (manager,
-	                                       miner,
-	                                       status,
-	                                       progress)) {
-		g_printerr (_("Could not get status from miner: %s"), miner);
-		return FALSE;
-	}
-
-	tracker_miner_manager_is_paused (manager,
-	                                 miner,
-	                                 pause_applications,
-	                                 pause_reasons);
-
-	return TRUE;
-}
-
 static gint
 miner_pause_details (void)
 {
@@ -394,12 +369,14 @@ miner_pause_details (void)
 			continue;
 		}
 
-		if (!miner_get_details (manager,
-		                        l->data,
-		                        NULL,
-		                        NULL,
-		                        &pause_applications,
-		                        &pause_reasons)) {
+		tracker_miner_manager_is_paused (manager,
+		                                 l->data,
+		                                 &pause_applications,
+		                                 &pause_reasons);
+
+		if (!pause_applications || !pause_reasons) {
+			/* unable to get pause details,
+			   already logged by tracker_miner_manager_is_paused */
 			continue;
 		}
 
